@@ -1,9 +1,4 @@
-use core::{cmp::min, marker::PhantomData};
-use primitive_types::{H160, H256, U256};
-use sha3::{Digest, Keccak256};
-
 use crate::{
-    collection::{vec::Vec, Map},
     db::Database,
     error::{ExitError, ExitReason, ExitSucceed},
     machine,
@@ -12,11 +7,16 @@ use crate::{
     opcode::gas,
     spec::{Spec, SpecId::*},
     subroutine::{Account, State, SubRoutine},
-    util, CallContext, CreateScheme, Env, ExitRevert, Inspector, Log, Transact, TransactOut,
-    TransactTo, Transfer, KECCAK_EMPTY,
+    util, CallContext, CreateScheme, Env, ExitRevert, Inspector, Log, TransactOut, TransactTo,
+    Transfer, KECCAK_EMPTY,
 };
+use alloc::vec::Vec;
 use bytes::Bytes;
+use core::{cmp::min, marker::PhantomData};
+use hashbrown::HashMap as Map;
+use primitive_types::{H160, H256, U256};
 use revm_precompiles::{Precompile, PrecompileOutput, Precompiles};
+use sha3::{Digest, Keccak256};
 
 pub struct EVMImpl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> {
     db: &'a mut DB,
@@ -27,6 +27,12 @@ pub struct EVMImpl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> {
     _phantomdata: PhantomData<GSPEC>,
 }
 
+pub trait Transact {
+    /// Do transaction.
+    /// Return ExitReason, Output for call or Address if we are creating contract, gas spend, State that needs to be applied.
+    fn transact(&mut self) -> (ExitReason, TransactOut, u64, State);
+}
+
 impl<'a, GSPEC: Spec, DB: Database, const INSPECT: bool> Transact
     for EVMImpl<'a, GSPEC, DB, INSPECT>
 {
