@@ -1,8 +1,6 @@
-use crate::{
-    collection::{vec, vec::Vec, Entry, Map},
-    models::SelfDestructResult,
-    ExitRevert, KECCAK_EMPTY,
-};
+use crate::{models::SelfDestructResult, ExitRevert, KECCAK_EMPTY};
+use alloc::{vec, vec::Vec};
+use hashbrown::{hash_map::Entry, HashMap as Map};
 
 use core::mem::{self};
 
@@ -277,6 +275,8 @@ impl SubRoutine {
         true
     }
 
+    const PRECOMPILE3: H160 = H160([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3]);
+
     #[inline]
     fn revert_account_changelog(
         state: &mut State,
@@ -289,7 +289,7 @@ impl SubRoutine {
             ChangeLog::PrecompileBalanceChange(original_balance, flag) => {
                 let acc = state.get_mut(&add).unwrap();
                 acc.info.balance = original_balance;
-                if add == H160::from_low_u64_be(3) {
+                if add == Self::PRECOMPILE3 {
                     acc.filth = Filth::Precompile(true);
                 } else {
                     acc.filth = Filth::Precompile(flag);
